iOSBuild Documentation
======================

This page contains the documentation for the `iOSBuild`_ project.

.. _iOSBuild: https://github.com/zwill22/iOSBuild

.. include:: ../README.md
   :parser: myst_parser.sphinx_

.. toctree:: 
   :maxdepth: 2
   :caption: Contents:
   
   about
   modules
   license

.. seealso::

   :doc: `contents`

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
